<?php

namespace Gnupo\Cli
{

	/**
	 * @author miguel.trias
	 */
	class OutputController
	{
		const R_ERROR   = 1;
		const R_WARNING = 2;
		const R_INFO    = 3;
		const R_NOTICE  = 4;
		const R_DEBUG   = 5;

		private static $instance;
		
		/**
		 * @var \Gnupo\Cli\Printer
		 */
		private $Printer;

		private $maximumRelevancyLevel;

		public static function getInstance()
		{
			if (!self::$instance instanceof self) self::$instance = new self();
			return self::$instance;
		}

		private function __construct()
		{
			$this->initialize();
		}

		private function initialize()
		{
			$this->Printer = new Printer();
			$this->maximumRelevancyLevel = self::R_INFO;
		}

		public function setMaxRelevancyLevel($level)
		{
			$this->maximumRelevancyLevel = $level;
		}

		public function coloredMessage($txt,$color)
		{
			echo PHP_EOL;
			$this->Printer->out($txt,$color);
		}

		public function blockMessage($txt,$relevancyLevel)
		{
			if ( $relevancyLevel <= $this->maximumRelevancyLevel )
			{
				$this->coloredMessage($txt,$this->getColorByRelevancyLevel($relevancyLevel));
			}
		}

		private function getColorByRelevancyLevel($relevancyLevel)
		{
			switch ($relevancyLevel)
			{
				case self::R_ERROR   : return Printer::COLOR_BOLD.Printer::COLOR_R;
				case self::R_WARNING : return Printer::COLOR_R;
				case self::R_INFO    : return Printer::COLOR_B;
				case self::R_NOTICE  : return Printer::COLOR_W;
				case self::R_DEBUG   : return Printer::COLOR_Y;
				default              : return Printer::COLOR_G;
			}
		}

	}
	
}