<?php

namespace Gnupo
{

	use \Gnupo\Cli\Printer          as Printer;
	use \Autoloading\Loader         as Loader;
	use \Gnupo\Cli\ArgumentParser   as ArgumentParser;
	use \Gnupo\Cli\ParameterHolder  as ParameterHolder;
	use \Gnupo\Cli\OutputController as OutputController;

	/**
	 * Main script to be runned from CLI environment
	 * @todo Set, parse and interpret a Help Parameter
	 */
	class Main
	{

		/**
		 * This method initializes all the runtime environment of the GnupoParser
		 * @todo Let configure maps caching path with a parameter
		 */
		public function initialize()
		{
			$basePath = realpath(__DIR__.DIRECTORY_SEPARATOR.'..'.DIRECTORY_SEPARATOR.'..').DIRECTORY_SEPARATOR;
			require_once $basePath . 'lib'. DIRECTORY_SEPARATOR . 'Autoloading' . DIRECTORY_SEPARATOR . 'Loader.class.php';
			$Loader = Loader::getInstance();
			$Loader->setMapsCachingPath($basePath . 'cache' . DIRECTORY_SEPARATOR . 'autoload-maps-cache');
			$Loader->setUseMapsCache(false);
			$Loader->addPath($basePath . 'lib');
		}

		private static $instance;

		public static function getInstance()
		{
			if (!(self::$instance instanceof self)) self::$instance = new self();
			return self::$instance;
		}

		private function __construct()
		{
			$this->initialize();
		}

		public function execute()
		{
			# Arguments Parsing
			$ParametersArray = ArgumentParser::parse($_SERVER['argv']);
			$ParameterHolder = new ParameterHolder($ParametersArray);
			$ParameterHolder->printAll();

			# Printer Instance (responsible of all the output)
			$Printer = new Printer();
			$Printer->out("Prueba", Printer::COLOR_G);

			# Output Controller (responsible of all structured output)
			$OutputController = OutputController::getInstance();
			$OutputController->setMaxRelevancyLevel(OutputController::R_WARNING);
			$OutputController->coloredMessage("Output from output controller",Printer::COLOR_R);
			$OutputController->coloredMessage("Another Output from output controller",Printer::COLOR_B);

			$OutputController->blockMessage("Testing block messages Error"  ,OutputController::R_ERROR);
			$OutputController->blockMessage("Testing block messages Warning",OutputController::R_WARNING);
			$OutputController->blockMessage("Testing block messages Info"   ,OutputController::R_INFO);
			$OutputController->blockMessage("Testing block messages Info"   ,OutputController::R_NOTICE);
			$OutputController->blockMessage("Testing block messages Info"   ,OutputController::R_DEBUG);

		}
	}

	$Main = Main::getInstance();
	$Main->execute();

}