<?php

namespace Gnupo\Runtime
{

/**
 * @author miguel.trias
 * @version 2009-09-07
 */

	/**
	 * Interface to be implemented by all the classes which objects must be persisted (Persistable Objects)
	 */
	interface Persistable
	{

		/**
		 * Persist this object in Database
		 */
		public function save ();


		/**
		 * Gets a Db connection (from the DAL) addecuate to persist objects of this class
		 * @param string $mode Mode required for the connection. This can be read-only, write-only or both (use constants defined in DAL)
		 * @return Gnupo\Dal\Connection
		 */
		static public function getDbConnection ($mode);

		/**
		 * Sets the ID property of a persisted object
		 * @throws \Gnupo\Runtime\Exception\ObjectIsNotPersistedYet
		 * @param integer $id
		 * @return void
		 */
		public function setId ($id);

		/**
		 * Returns the persistor object for this class (Table-Data-Gateway Pattern) 
		 * Implementa Persistable
		 * @return \Gnupo\Runtime\Persistor
		 */
		public static function getTablegateway();

		/**
		 * Returns the name of the table in wich objects of this class are stored
		 * @return string
		 */
		public static function getTablename();

	}
}